<?php
header('Content-Type: application/json');

// Include database connection
include 'api.php';

// Get parameters
$search = isset($_GET['search']) ? $_GET['search'] : '';
$limit = isset($_GET['limit']) ? (int)$_GET['limit'] : 10;
$offset = isset($_GET['offset']) ? (int)$_GET['offset'] : 0;
$order = isset($_GET['order']) ? $_GET['order'] : 'id';
$orderType = isset($_GET['orderType']) ? $_GET['orderType'] : 'desc';

// Validate order and orderType
$validOrders = ['id', 'title', 'created_at', 'keywords', 'title_slug'];
$validOrderTypes = ['asc', 'desc'];

if (!in_array($order, $validOrders)) {
    $order = 'id';
}

if (!in_array($orderType, $validOrderTypes)) {
    $orderType = 'desc';
}

// Build SQL query
$sql = "SELECT * FROM posts 
        WHERE 
         keywords LIKE ? 
        OR title_slug LIKE ?
        ORDER BY $order $orderType 
        LIMIT ? OFFSET ?";

// Prepare and execute statement
$stmt = $conn->prepare($sql);

$searchTerm = "%$search%";
$stmt->bind_param('ssii', $searchTerm, $searchTerm, $limit, $offset);

// For debugging, build the query with actual parameters
$debugSql = str_replace(['?', '?', '?', '?'], 
                         [$conn->real_escape_string($searchTerm), 
                          $conn->real_escape_string($searchTerm), 
                          (int)$limit, 
                          (int)$offset], 
                         $sql);

echo "<pre>Debug SQL Query: $debugSql</pre>";

// Execute the statement
$stmt->execute();

// Get results
$result = $stmt->get_result();
$posts = [];

while ($row = $result->fetch_assoc()) {
    $posts[] = $row;
}

// Output results in JSON format
echo json_encode($posts);

// Close connection
$stmt->close();
$conn->close();
?>
