<?php
header("Content-Type: application/json");

class MagazineAPI {
    private $db;
    private $table = 'ktbl_magazine';  

    public function __construct() {
        $database = new Database();
        $this->db = $database->connect();
    }

    public function handleRequest() {
        $request = explode('/', trim($_SERVER['REQUEST_URI'], '/')); 
        
        if (count($request) >= 2 && $request[0] === 'magazine' && !empty($request[1])) {
            $magaType = $request[2];
            $page = isset($request[3]) ? (int)$request[3] : 1;
            $limit = isset($request[4]) ? (int)$request[4] : 10;

            // Ensure page and limit are positive integers
            $page = max($page, 1);
            $limit = max($limit, 1);

            $this->getMagazinesByType($magaType, $page, $limit);
        } else {
            $this->respondNotFound();
        }
    }

    private function getMagazinesByType($magaType, $page, $limit) {
        $magaType = $this->db->real_escape_string($magaType); // Sanitize the input

        // Calculate the offset for pagination
        $offset = ($page - 1) * $limit;

        // Prepare the query with LIMIT and OFFSET for pagination
        $query = "SELECT * FROM " . $this->table . " WHERE maga_type = '$magaType' LIMIT $limit OFFSET $offset";
        $result = $this->db->query($query);

        if ($result->num_rows > 0) {
            $magazines = [];
            while ($row = $result->fetch_assoc()) {
                $magazines[] = $row;
            }
            echo json_encode([
                "status" => true,
                "data" => $magazines,
                "page" => $page,
                "limit" => $limit
            ]);
        } else {
            echo json_encode(["status" => false, "message" => "No magazines found for the specified type."]);
        }
    }

    private function respondNotFound() {
        echo json_encode(["status" => false, "message" => "Invalid request"]);
    }
}

$api = new MagazineAPI();
$api->handleRequest();
?>
