<?php
header("Content-Type: application/json");
error_reporting(E_ALL);
ini_set('display_errors', 1);

class NotificationStatusAPI {
    private $db;
    private $table = 'fcmtoken';  

    public function __construct() {
        $database = new Database();
        $this->db = $database->connect();
    }

    public function handleRequest() {
        $request = explode('/', trim($_SERVER['REQUEST_URI'], '/'));  
        if ($_SERVER['REQUEST_METHOD'] === 'GET') {
            $this->getTokenByDeviceId($request);
        } elseif ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $this->handlePostRequest();
        } else {
            $this->respondNotFound();
        }
    }

    private function handlePostRequest() {
        $request = explode('/', trim($_SERVER['REQUEST_URI'], '/')); 
        if (isset($request[2]) && $request[2] == 'notistatus') {
            $this->notiStatus();
        } else {
            $this->notiSett();
        }
    }

 private function notiSett() {
    // Read and decode JSON input
    $data = json_decode(file_get_contents("php://input"));

    // Validate required fields
    if (empty($data->device_id) || empty($data->fcm_token)) {
        echo json_encode(["status" => false, "message" => "Device ID and FCM token are required."]);
        return;
    }

    $device_id = $this->db->real_escape_string($data->device_id);
    $fcm_token = $this->db->real_escape_string($data->fcm_token);
    $fcm_status = 'Yes';  // Assuming default status is 'Yes'
    $fcm_date = date('Y-m-d H:i:s');
    $fcm_update = date('Y-m-d H:i:s');
    $noti_status = isset($data->notifications_enabled) ? $this->db->real_escape_string($data->notifications_enabled) : 'No';
    
    // Validate and encode JSON for category_notifications
    $cat_status = '{}';  // Default empty JSON object
    if (isset($data->category_notifications) && is_object($data->category_notifications)) {
        $cat_status = json_encode($data->category_notifications);
        if (json_last_error() !== JSON_ERROR_NONE) {
            echo json_encode(["status" => false, "message" => "Invalid JSON format for category_notifications."]);
            return;
        }
    }

    // New fields with default values
    $night_notifications = isset($data->night_notifications_enabled) ? $this->db->real_escape_string($data->night_notifications_enabled) : 'No';
    $auto_refresh = isset($data->auto_refresh_enabled) ? $this->db->real_escape_string($data->auto_refresh_enabled) : 'No';

    // Check if device_id already exists
    $query = "SELECT id FROM " . $this->table . " WHERE device_id = ?";
    $stmt = $this->db->prepare($query);
    if (!$stmt) {
        echo json_encode(["status" => false, "message" => "Prepare statement failed: " . $this->db->error]);
        return;
    }

    $stmt->bind_param("s", $device_id);
    if (!$stmt->execute()) {
        echo json_encode(["status" => false, "message" => "Execute failed: " . $stmt->error]);
        return;
    }

    $stmt->store_result();
    if ($stmt->num_rows > 0) {
        // Device exists, update
        $updateQuery = "UPDATE " . $this->table . " SET fcm_token = ?, fcm_status = ?, fcm_update = ?, noti_status = ?, cat_status = ?, night_notifications = ?, auto_refresh = ? WHERE device_id = ?";
        $updateStmt = $this->db->prepare($updateQuery);
        if (!$updateStmt) {
            echo json_encode(["status" => false, "message" => "Prepare statement failed: " . $this->db->error]);
            return;
        }

        // Bind parameters and execute the query
        $updateStmt->bind_param("ssssssss", $fcm_token, $fcm_status, $fcm_update, $noti_status, $cat_status, $night_notifications, $auto_refresh, $device_id);

        if ($updateStmt->execute()) {
            echo json_encode(["status" => true, "message" => "Device token and status updated successfully."]);
        } else {
            echo json_encode(["status" => false, "message" => "Failed to update device token and status: " . $updateStmt->error]);
        }
    } else {
        // Device does not exist, insert new record
        $insertQuery = "INSERT INTO " . $this->table . " (device_id, fcm_token, fcm_status, fcm_date, noti_status, cat_status, night_notifications, auto_refresh) VALUES (?, ?, ?, ?, ?, ?, ?, ?)";
        $insertStmt = $this->db->prepare($insertQuery);
        if (!$insertStmt) {
            echo json_encode(["status" => false, "message" => "Prepare statement failed: " . $this->db->error]);
            return;
        }

        $insertStmt->bind_param("ssssssss", $device_id, $fcm_token, $fcm_status, $fcm_date, $noti_status, $cat_status, $night_notifications, $auto_refresh);
        if ($insertStmt->execute()) {
            echo json_encode(["status" => true, "message" => "Device token and status inserted successfully."]);
        } else {
            echo json_encode(["status" => false, "message" => "Failed to insert device token and status: " . $insertStmt->error]);
        }
    }
}




    private function getTokenByDeviceId($request) {
        if (isset($request[2])) {
            $device_id = $this->db->real_escape_string($request[2]);
        } else {
            echo json_encode(["status" => false, "message" => "Device ID is required."]);
            return;
        }

        // Prepare and execute query
        $query = "SELECT * FROM " . $this->table . " WHERE device_id = ?";
        $stmt = $this->db->prepare($query);
        if (!$stmt) {
            echo json_encode(["status" => false, "message" => "Prepare statement failed: " . $this->db->error]);
            return;
        }

        $stmt->bind_param("s", $device_id);
        if (!$stmt->execute()) {
            echo json_encode(["status" => false, "message" => "Execute failed: " . $stmt->error]);
            return;
        }

        $result = $stmt->get_result();
        if ($result->num_rows > 0) {
            $data = $result->fetch_assoc();
            echo json_encode(["status" => true, "data" => $data]);
        } else {
            echo json_encode(["status" => false, "message" => "No data found for the given Device ID."]);
        }
    }

    private function respondNotFound() {
        echo json_encode(["status" => false, "message" => "Invalid request"]);
    }
}

// Create instance and handle the request
$api = new NotificationStatusAPI();
$api->handleRequest();
