<?php

class JWT {
    private static $secret_key = 'KUMUDAM'; // Replace with your own secret key
    private static $algorithm = 'HS256'; // Hashing algorithm

    // Base64Url encode
    private static function base64UrlEncode($data) {
        return str_replace(['+', '/', '='], ['-', '_', ''], base64_encode($data));
    }

    // Create JWT token
    public static function createToken($user, $expiry = 3600) {
        $header = json_encode(['typ' => 'JWT', 'alg' => self::$algorithm]);
        $payload = json_encode([
            'userid' => $user['user_id'],
            'emailid' => $user['user_email'],
            'name' => $user['user_firstname'],
            'iat' => time(),
            'exp' => time() + $expiry // Token valid for specified time
        ]);

        // Base64Url encode the header and payload
        $base64UrlHeader = self::base64UrlEncode($header);
        $base64UrlPayload = self::base64UrlEncode($payload);

        // Create the signature hash
        $signature = hash_hmac('sha256', "$base64UrlHeader.$base64UrlPayload", self::$secret_key, true);
        $base64UrlSignature = self::base64UrlEncode($signature);

        // Return the generated JWT token
        return "$base64UrlHeader.$base64UrlPayload.$base64UrlSignature";
    }

    // Create Refresh Token
    public static function createRefreshToken($user) {
        return bin2hex(random_bytes(32));  
    }

    // Validate JWT token
    public static function validateToken($token) {
        $parts = explode('.', $token);
        if (count($parts) === 3) {
            list($header, $payload, $signature) = $parts;

            // Verify the signature
            $validSignature = self::base64UrlEncode(hash_hmac('sha256', "$header.$payload", self::$secret_key, true));
            if ($signature === $validSignature) {
                $decodedPayload = json_decode(base64_decode($payload), true);
                if ($decodedPayload['exp'] > time()) {
                    return $decodedPayload; // Token is valid
                }
            }
        }

        return false; // Token is invalid
    }
}
?>
